/**
 * Application configuration
 */
import { BryntumTaskBoardProps } from '@bryntum/taskboard-react';

const taskData: any = [
    {
      id: 1,
      name: "Order materials",
      description:
        "Crucial that the materials are available when they are needed",
      status: "Done",
      prio: "High",
      feature: "Audio",
      team: "Release 2",
      iconCls: "box",
    },
    {
      id: 2,
      name: "Construct trusses",
      description: "Double check the dimensions with the architect",
      status: "Todo",
      prio: "Medium",
      feature: "Video",
      team: "Release 1",
      iconCls: "home",
    },
    {
      id: 3,
      name: "Raise walls",
      description:
        "Timo at the factory will notify us when they have finished construction",
      status: "Todo",
      prio: "Medium",
      feature: "Video",
      team: "Release 1",
      iconCls: "hammer",
    },
    {
      id: 4,
      name: "Polish concrete",
      description:
        "Bottom floor should have polished concrete floors according to the architect",
      status: "Todo",
      prio: "Low",
      feature: "Picture",
      team: "Release 4",
    },
    {
      id: 5,
      name: "Paint the ceilings",
      description: "Glossy white",
      status: "Todo",
      prio: "Medium",
      feature: "Video",
      team: "Release 6",
      iconCls: "paint-roller",
    },
    {
      id: 6,
      name: "Create conceptual drawings",
      description: "Be quick, use Sketchup",
      status: "Done",
      prio: "Medium",
      feature: "Video",
      team: "Release 3",
      iconCls: "pen-fancy",
    },
    {
      id: 7,
      name: "Create construction drawings",
      description:
        "Based on Release 3 conceptual drawings, be sure to calculate everything properly",
      status: "Done",
      prio: "Medium",
      feature: "Video",
      team: "Release 5",
      iconCls: "pencil-ruler",
    },
    {
      id: 8,
      name: "Pay subcontractors",
      description: "Dont want them displeased as last time",
      status: "Doing",
      prio: "High",
      feature: "Audio",
      team: "Release 2",
      iconCls: "coins",
    },
    {
      id: 9,
      name: "Review agreements",
      description: "Emphasis the joint responsibility",
      status: "Done",
      prio: "Medium",
      feature: "Video",
      team: "Release 2",
    },
    {
      id: 10,
      name: "Cast foundation",
      description:
        "Try the new speed dryer acquired for the last project, heard it worked great",
      status: "Doing",
      prio: "Medium",
      feature: "Video",
      team: "Release 4",
    },
    {
      id: 11,
      name: "Build 1:50 model",
      description: "Cardboard was requested, 3D print trees etc",
      status: "Todo",
      prio: "Low",
      feature: "Picture",
      team: "Release 3",
      iconCls: "tree",
    },
    {
      id: 12,
      name: "Estimate beam dimensions",
      description: "Factor snow weight in, roof is pretty flat",
      status: "Done",
      prio: "High",
      feature: "Audio",
      team: "Release 1",
      iconCls: "question-circle",
    },
  ];

  const usersData: any = [
    {
      id: 1,
      name: "Sam Jones",
      team: "Release 1",
      image: "angelo.jpg",
    },
    {
      id: 2,
      name: "Matt Donovan",
      team: "Release 1",
      image: "henrik.jpg",
    },
    {
      id: 3,
      name: "Jenny Logan",
      team: "Release 2",
      image: "gloria.jpg",
    },
    {
      id: 4,
      name: "Mathias Jonson",
      team: "Release 3",
      image: "mike.jpg",
    },
    {
      id: 5,
      name: "Andrea Lloyd",
      team: "Release 3",
      image: "macy.jpg",
    },
    {
      id: 6,
      name: "Liam Johansen",
      team: "Release 4",
      image: "arcady.jpg",
    },
    {
      id: 7,
      name: "Amanda Moore",
      team: "Release 5",
      image: "madison.jpg",
    },
    {
      id: 8,
      name: "George Carson",
      team: "Release 6",
      image: "dan.jpg",
    },
    {
      id: 9,
      name: "Mandy Stevenson",
      team: "Release 1",
      image: "linda.jpg",
    },
    {
      id: 10,
      name: "Max Williams",
      team: "Release 4",
      image: "maxim.jpg",
    },
  ];

  const useTaskBoardConfig = (handleAddButtonClick: any): BryntumTaskBoardProps => {
    return {
      useDomTransition: true, // Experimental, transition moving cards using the editor
      showCountInHeader: false, // Demo will render its own counters, disable built in
      // stickyHeaders     : true,  // Want headers to stick to the top

      swimlaneDragFeature: true,
      // Columns
      columnField: "feature",
      columns: [
        { id: "Audio", text: "Audio", color: "orange" },
        { id: "Video", text: "Video", color: "yellow" },
        { id: "Picture", text: "Picture", color: "light-green" },
      ],

      // Swimlanes
      swimlaneField: "team",
      swimlanes: [
        "Release 1",
        "Release 2",
        "Release 3",
        "Release 4",
        "Release 5",
        "Release 6",
      ],

      // Customize swimlane markup
    swimlaneRenderer({ swimlaneRecord, swimlaneConfig }: any) {
      const team = swimlaneRecord.id,
        members = usersData.filter((r: any) => r.team === team),
        memberCount = members.length,
        taskCount = swimlaneRecord.tasks.length;
      console.log("teams", team);
      console.log("member ", members);
      console.log("member count", memberCount);
      console.log("taskCount   ", taskCount);

      // Display member and task count in the header
      swimlaneConfig.children.header.children.info = {
        class: "team-info",
        text: `${memberCount} member${
          memberCount !== 1 ? "s" : ""
        }, ${taskCount} task${taskCount !== 1 ? "s" : ""}`,
      };

      // Display team members before first column in the swimlane
      swimlaneConfig.children.body.children.unshift({
        class: "team-members",
        children: members.map((member :any) => ({
          class: "member",
          elementData: {
            member,
          },
          children: [`${member?.name}`],
        })),
      });
    },

      // Customize card markup
    taskRenderer({ taskRecord, cardConfig }: any) {
      // Add an icon to card headers (positioned first using CSS `order`, see app.scss)
      console.log('cardConfig', cardConfig);
      cardConfig.children.header.children.icon = {
        tag: "i",
        class:
          "b-fa " +
          (taskRecord.iconCls ? `b-fa-${taskRecord.iconCls}` : "b-fa-tasks"),
      };
      cardConfig.children.body.children.section = {
        tag: "div",
        class: 'div',
        text: `${taskRecord.feature}, ${taskRecord.status}, ${taskRecord.team}`
      };
    },

    stretchCards: true,

    // Project using inline data
    project: {
      tasksData: taskData,
    },

    features: {
      columnDrag: true,
    },

    tbar: [
      {
        type    : 'button',
        text    : 'Add swimlane',
        icon    : 'b-fa-plus-circle',
        onClick : handleAddButtonClick
      },
      // Field for filtering tasks
      { type: "taskfilterfield" },
      // Field for filtering columns
      { type: "columnfilterfield" },
      // Field for filtering swimlanes
      { type: "swimlanefilterfield" },
      // Move the last items to the right
      '->',
      // Button to pick which columns are shown
      { type : 'columnpickerbutton' },
      // Button to pick which swimlanes are shown
      { type : 'swimlanepickerbutton' },
    ]
  }
};

export { useTaskBoardConfig };
